@@ -1,7 +1,7 @@
 # Human friendly input/output in Python.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: July 13, 2018
+# Last Change: July 14, 2018
 # URL: https://humanfriendly.readthedocs.io
 
 """
@@ -51,6 +51,8 @@ __all__ = (
     'is_string',
     'is_unicode',
     'monotonic',
+    'name2codepoint',
+    'unichr',
     'unicode',
     'unittest',
 )
@@ -58,17 +60,21 @@ __all__ = (
 try:
     # Python 2.
     unicode = unicode
+    unichr = unichr
     basestring = basestring
     interactive_prompt = raw_input
     from HTMLParser import HTMLParser
     from StringIO import StringIO
+    from htmlentitydefs import name2codepoint
 except (ImportError, NameError):
     # Python 3.
     unicode = str
+    unichr = chr
     basestring = str
     interactive_prompt = input
     from html.parser import HTMLParser
     from io import StringIO
+    from html.entities import name2codepoint
 
 try:
     # Python 3.3 and higher.
